/* BEGIN_COMMON_COPYRIGHT_HEADER
 * (c)LGPL2+
 *
 * LXQt - a lightweight, Qt based, desktop toolset
 * https://lxqt.org
 *
 * Copyright: 2012 Razor team
 * Authors:
 *   Christian Surlykke <christian@surlykke.dk>
 *
 * This program or library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * END_COMMON_COPYRIGHT_HEADER */
#ifndef LIDWATCHER_H
#define LIDWATCHER_H

#include <QObject>
#include <QTime>
#include <QDBusUnixFileDescriptor>

#include <LXQt/Power>

#include "../config/powermanagementsettings.h"
#include "watcher.h"
#include "lid.h"

class LidWatcher : public Watcher
{
    Q_OBJECT
public:
    explicit LidWatcher(QObject *parent = nullptr);
    ~LidWatcher() override;

private slots:
    void lidChanged(bool closed);

private:
    int action();
    bool externalMonitorPlugged();
    void inhibitSystemdLogin();

    Lid mLid;
    LXQt::Power mLXQtPower;
    PowerManagementSettings mSettings;
    QDBusUnixFileDescriptor logindLock;
};

#endif // LIDWATCHER_H
